#
# spec file for package libabigail
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libabigail
%define lname   libabigail0
Version:        1.8.2
Release:        bp155.2.14
Summary:        Application Binary Interface Generic Analysis and Instrumentation Library
License:        GPL-3.0-or-later AND LGPL-2.0-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://sourceware.org/libabigail/

Source:         %name-%version.tar.xz
Patch1:         no-tests.diff
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake >= 1.11.1
BuildRequires:  dpkg
BuildRequires:  gcc-c++ >= 4.7
BuildRequires:  libdw-devel >= 0.170
%if 0%{?suse_version} < 1550 && 0%{?sle_version} < 150400
BuildRequires:  libebl-devel
%endif
BuildRequires:  libtool >= 2.2
BuildRequires:  libzip-devel
BuildRequires:  makeinfo
BuildRequires:  pkg-config
BuildRequires:  python3-Sphinx
BuildRequires:  xz
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.22
BuildRequires:  pkgconfig(libzip) >= 0.10
Requires(post): %install_info_prereq
Requires(postun): %install_info_prereq

%description
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program.

%package -n %lname
Summary:        Application Binary Interface Generic Analysis and Instrumentation Library
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program. The
library provides a way to compare two ABI corpuses, provide detailed
information about their differences, and help build tools to infer
interesting conclusions about these differences.

%package devel
Summary:        Development files for the ABI-relevant artifact library
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program. The
library provides a way to compare two ABI corpuses, provide detailed
information about their differences.

This subpackage contains the files needed to build programs with ABIGAIL.

%package tools
Summary:        Utilities to inspect ABI-relevant artifacts
License:        LGPL-3.0-or-later
Group:          Development/Tools/Other

%description tools
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program.

This subpackage contains the ABIGAIL utilities allowing to infer
interesting conclusions about these differences.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --includedir="%_includedir/%name" --docdir="%_docdir/%name" \
	--disable-static --enable-cxx11 --disable-silent-rules
make %{?_smp_mflags}
pushd doc/manuals
make man info
popd

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

pushd doc/manuals
make DESTDIR=%buildroot install-man-and-info-doc
popd

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%post tools
%install_info --info-dir=%_infodir %_infodir/abigail.info.gz

%postun tools
%install_info_delete --info-dir=%_infodir %_infodir/abigail.info.gz

%files -n %lname
%_libdir/libabigail.so.0*

%files devel
%_includedir/%name/
%_libdir/libabigail.so
%_libdir/pkgconfig/*.pc
%_datadir/aclocal/
%_mandir/man7/libabigail.7.gz

%files tools
%license COPYING*
%_bindir/abi*
%_bindir/kmidiff
%_mandir/man1/abi*.1*
%_infodir/abigail.info.gz
%_libdir/%name/

%changelog
* Wed Jan 12 2022 Max Lin <mlin@suse.com>
- Do not BuildRequires libebl-devel for Leap 15.4
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8.2:
  * dwarf-reader: Keep stable order when de-duplicating class definitions
- Update to version 1.8.1:
  * Fix potential loss of some aliased ELF function symbols
  * Ignore duplicated functions and those not associated with ELF symbols
  * dwarf-reader: Support fast DW_FORM_line_strp string comparison
  * abidiff: support --dump-diff-tree with --leaf-changes-only
- Update to version 1.8:
  * abipkgdiff:
  * Add a new --self-check option
  * make --self-check to fail on any change against own ABIXML
  * Fix race condition while using private types suppr specs
  * abidw:
  * make --abidiff report any change against own ABIXML
  * Add --drop-private-types and --drop-undefined-syms options
  * abidiff, abidw: Support several --headers-dir{1,2} options
  * abg-writer: Add support for stable hash type ids.
  * dwarf-reader:
  * Support several anonymous data members in a given class
  * Support declaration-only enums
  * Support artificially generated translation units
  * Fix bloom filter access in GNU_HASH section
  * Support DWARF5
- Require libdw >= 170 for DWARF5 features
- Update no-tests.diff
* Tue Apr 21 2020 Steve Kowalik <steven.kowalik@suse.com>
- Shift BuildRequires to Python 3 Sphinx due to removal of Python 2.
* Sun Mar 15 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7
  * Fix ELF reader not inteprreting interpret ksymtab with
    kernel 4.19+
  * Support string form DW_FORM_strx{1,4} from DWARF 5.
  * Support decl DIEs referring to symbols using DW_AT_ranges.
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 1.7~git84
  * Initial support for Ada ranges.
  * Initial support of anonymous data members.
  * Represent sizes and offsets in bytes and hexadecimal values.
  * Initial basic support of union type in suppression
    specifications.
  * Filter out changes like type to const type.
  * Explicitely detect anonymous data member changes.
  * Use the flat representation for anonymous struct/unions.
  * Better detect when pointer and qualified types carry local
    changes.
  * Better detect when diff nodes only carry local type changes.
  * Better support array with unknown upper bound.
  * Categorize CV qualifier changes on fn return types as harmless.
  * Support some new DWARF language encoding for C and C++.
  * Support having several debuginfo search dirs for a binary.
* Thu Aug 17 2017 jengelh@inai.de
- Update to snapshot 1.0~rc6+git185
  * Create a Corpus Group API extension
  * Initial support to lookup types per location
  * Support loading and comparing two kernel trees
  * Avoid loading a translation unit twice from abixml
  * Introduce the --kmi-whitelist option to abidiff and abidw
  * Avoid emitting duplicated decls in abixml
  * Avoid emitting some empty translation units to abixml
  * Avoid de-duplicating different C types that have identical name
  * Allow selective resolution of class declaration
  * Speedup DIE representation computing esp function signature in C
  * Do not report about voffset when it's not set in debug info
  * Cache function type name computation results
  * Filter top cv qualifier changes on function parameter types
  * Support ELF symbol visibility property
  * Avoid crashing when the elf file could not be read
* Sun May 28 2017 jengelh@inai.de
- Update to snapshot 1.0~rc6+git126
  * Add support for .deb files to abipkgdiff
  * abipkgdiff: automatically recurse into directories and
    .tar archives
  * abidw: new options --no-architecture, --stats, --noout,
  - -abidiff, --verbose
  * abidiff: new options --no-architecture, --stats, --verbose
  * Support new 'accessed_through' suppression property
  * Report vtable changes in top-level function change reports
  * Add --d{1,2} shortcut options for --debug-info-dir{1,2}
    in abidiff
  * abipkgdiff: new options --verbose, --no-added-binaries,
  - -keep-tmp-files, --no-added-syms
- Add no-tests.diff
* Thu Nov 26 2015 pth@suse.de
- BuildRequire python-sphinx so that the documentation can be built.
- BuildRequire makeinfo.
- Build man pagres and info documentation and package them.
* Sun Mar  1 2015 jengelh@inai.de
- Update to new git snapshot 0~git791
  * Build the set of exported decls directly during DWARF loading
  * Do not miss canonicalizing opportunities on non-member class types
  * Stick qualified, pointer, reference and array types into the
  global scope
  * Do not forget to canonicalize enum underlying type and void type
  * Speed up symbol version reading
* Fri Jan  9 2015 jengelh@inai.de
- Update to new git snapshot 0~git731
  * Support evaluating the SONAME from ELF files
  * Try harder to detect a DWARF attribute pointing into alternate DWARF section
  * Extend detection of compatible types to arrays
  * Detect and report changes in ELF architecture
* Sun Dec  7 2014 jengelh@inai.de
- Update to new git snapshot 0~git697
  * Fix a crash while writing symbol information
  * Initial implementation of the abicompat tool
  * Support reading undefined symbols from an ELF file
  * Sort functions by the their qualified name
* Fri Sep 12 2014 jengelh@inai.de
- Initial package for build.opensuse.org (version 0~git570)
